@@ -45,7 +45,7 @@ class RepairWorker(TentaclesWorker):
         await self.tentacles_setup_manager.create_missing_tentacles_arch()
         self.reset_worker()
         self.progress = 1
-        existing_tentacles = await load_tentacle_with_metadata(self.tentacle_path)
+        existing_tentacles = load_tentacle_with_metadata(self.tentacle_path)
         self.total_steps = len(existing_tentacles)
         await gather(*[self._repair_tentacle(tentacle) for tentacle in existing_tentacles])
         await self.tentacles_setup_manager.refresh_user_tentacles_setup_config_file()
