@@ -27,7 +27,7 @@ from octobot_tentacles_manager.api.installer import install_all_tentacles, insta
 from octobot_tentacles_manager.configuration.tentacles_setup_configuration import TentaclesSetupConfiguration
 from octobot_tentacles_manager.constants import TENTACLES_PATH, TENTACLES_REQUIREMENTS_INSTALL_TEMP_DIR, \
     PYTHON_INIT_FILE, TENTACLES_NOTIFIERS_PATH, USER_TENTACLE_CONFIG_PATH, CONFIG_TENTACLES_FILE, \
-    USER_TENTACLE_SPECIFIC_CONFIG_PATH
+    USER_TENTACLE_SPECIFIC_CONFIG_PATH, TENTACLES_SERVICES_PATH, TENTACLES_BACKTESTING_PATH
 from octobot_tentacles_manager.managers.tentacles_setup_manager import TentaclesSetupManager
 
 # All test coroutines will be treated as marked.
@@ -69,13 +69,17 @@ async def test_repair_installation():
     assert await repair_installation(bot_path=broken_install) == 0
 
     # restore Notifiers directory
-    assert path.isfile(path.join(broken_tentacles, TENTACLES_NOTIFIERS_PATH, PYTHON_INIT_FILE))
+    assert path.isdir(path.join(broken_tentacles, TENTACLES_SERVICES_PATH, TENTACLES_NOTIFIERS_PATH))
+
+    # restore backtesting init file
+    assert path.isfile(path.join(broken_tentacles, TENTACLES_BACKTESTING_PATH, PYTHON_INIT_FILE))
 
     # restore main __init__ content
     with open(path.join(broken_tentacles, PYTHON_INIT_FILE)) as f:
         stripped_lines = [line.strip() for line in f.readlines()]
         assert "from .Trading import *" in stripped_lines
-        assert "from .Interfaces import *" in stripped_lines
+        assert "from .Backtesting import *" in stripped_lines
+        assert "from .Interfaces import *" not in stripped_lines
 
     # restore Evaluator/Realtime  __init__ content
     rt_path = path.join(broken_tentacles, "Evaluator", "RealTime")
